@@ -25,6 +25,8 @@ class TestArrowToFromAnnotation:
         ("prediction_3_classes.json", 4),
         ("prediction_4_bbox_and_classes.json", 5),
         ("prediction_2_keypoints_2_objects.json", 6),
+        ("prediction_11_timestamp.json", 7),
+        ("prediction_12_texts.json", 8),
     ])
     def test_prediction_from_file(self, file_name, n):
         test_json = resources.files(files) / file_name
